==> 0.0.2.tar.gz: android/src/main/kotlin/com/example/waves_sdk/WavesCryptoHandler.kt <==
package com.example.waves_sdk

import com.wavesplatform.sdk.WavesSdk
import com.wavesplatform.sdk.crypto.WavesCrypto
import com.wavesplatform.sdk.utils.Environment
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

class WavesCryptoHandler {

  fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {

    if (call.method == "keyPair") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "seed")
      val r = WavesCrypto.keyPair(prop)
      val data = mapOf("publicKey" to r.publicKey, "privateKey" to r.privateKey)
      return result.success(data)
    }

    if (call.method == "publicKey") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "seed")
      return result.success(WavesCrypto.publicKey(prop))
    }

    if (call.method == "privateKey") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "seed")
      return result.success(WavesCrypto.privateKey(prop))
    }

    if (call.method == "addressByPublicKey") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "publicKey")
      return result.success(WavesCrypto.addressByPublicKey(prop, null))
    }

    if (call.method == "addressBySeed") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "seed")
      return result.success(WavesCrypto.addressBySeed(prop, null))
    }

    if (call.method == "randomSeed") {
      return result.success(WavesCrypto.randomSeed())
    }

    if (call.method == "signBytesWithPrivateKey") {
      val prop: ByteArray = call.argument("bytes") ?: return result.error("Waves SDK", "Invalid props", "bytes")
      val prop2: String = call.argument("privateKey") ?: return result.error("Waves SDK", "Invalid props", "privateKey")
      return result.success(WavesCrypto.signBytesWithPrivateKey(prop, prop2))
    }

    if (call.method == "signBytesWithSeed") {
      val prop: ByteArray = call.argument("bytes") ?: return result.error("Waves SDK", "Invalid props", "bytes")
      val prop2: String = call.argument("seed") ?: return result.error("Waves SDK", "Invalid props", "seed")
      return result.success(WavesCrypto.signBytesWithSeed(prop, prop2))
    }

    if (call.method == "verifySignature") {
      val prop: String = call.argument("publicKey") ?: return result.error("Waves SDK", "Invalid props", "publicKey")
      val prop2: ByteArray = call.argument("bytes") ?: return result.error("Waves SDK", "Invalid props", "bytes")
      val prop3: ByteArray = call.argument("signature") ?: return result.error("Waves SDK", "Invalid props", "signature")
      return result.success(WavesCrypto.verifySignature(prop, prop2, prop3))
    }

    if (call.method == "verifyPublicKey") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "publicKey")
      return result.success(WavesCrypto.verifyPublicKey(prop))
    }

    if (call.method == "verifyAddress") {
      val prop: String = call.argument("address") ?: return result.error("Waves SDK", "Invalid props", "address")
      val prop2: String? = call.argument("publicKey")
      return result.success(WavesCrypto.verifyAddress(prop, null, prop2))
    }

    result.notImplemented()
  }
}

==> 0.1.3.tar.gz: android/src/main/kotlin/com/example/waves_sdk/WavesCryptoHandler.kt <==
package com.example.waves_sdk

import android.util.Log
import com.wavesplatform.sdk.crypto.WavesCrypto
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

class WavesCryptoHandler {

  fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {

    if (call.method == "keyPair") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "seed")
      val r = WavesCrypto.keyPair(prop)
      val data = mapOf("publicKey" to r.publicKey, "privateKey" to r.privateKey)
      return result.success(data)
    }

    if (call.method == "publicKey") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "seed")
      return result.success(WavesCrypto.publicKey(prop))
    }

    if (call.method == "privateKey") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "seed")
      return result.success(WavesCrypto.privateKey(prop))
    }

    if (call.method == "addressByPublicKey") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "publicKey")
      return result.success(WavesCrypto.addressByPublicKey(prop, null))
    }

    if (call.method == "addressBySeed") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "seed")
      return result.success(WavesCrypto.addressBySeed(prop, null))
    }

    if (call.method == "randomSeed") {
      return result.success(WavesCrypto.randomSeed())
    }

    if (call.method == "signBytesWithPrivateKey") {
      val bytes: ByteArray = call.argument("bytes") ?: return result.error("Waves SDK", "Invalid props", "bytes")
      val privateKey: String = call.argument("privateKey") ?: return result.error("Waves SDK", "Invalid props", "privateKey")

      return result.success(WavesCrypto.signBytesWithPrivateKey(bytes, privateKey))
    }

    if (call.method == "signBytesWithSeed") {
      val bytes: ByteArray = call.argument("bytes") ?: return result.error("Waves SDK", "Invalid props", "bytes")
      val seed: String = call.argument("seed") ?: return result.error("Waves SDK", "Invalid props", "seed")

      return result.success(WavesCrypto.signBytesWithSeed(bytes, seed))
    }

    if (call.method == "verifySignature") {
      val publicKey: String = call.argument("publicKey") ?: return result.error("Waves SDK", "Invalid props", "publicKey")
      val bytes: ByteArray = call.argument("bytes") ?: return result.error("Waves SDK", "Invalid props", "bytes")
      val signature: ByteArray = call.argument("signature") ?: return result.error("Waves SDK", "Invalid props", "signature")

      return result.success(WavesCrypto.verifySignature(publicKey, bytes, signature))
    }

    if (call.method == "verifyPublicKey") {
      val prop: String = call.arguments() ?: return result.error("Waves SDK", "Invalid props", "publicKey")

      return result.success(WavesCrypto.verifyPublicKey(prop))
    }

    if (call.method == "verifyAddress") {
      val prop: String = call.argument("address") ?: return result.error("Waves SDK", "Invalid props", "address")
      val prop2: String? = call.argument("publicKey")

      return result.success(WavesCrypto.verifyAddress(prop, null, prop2))
    }

    result.notImplemented()
  }
}
